from toga.style.pack import Pack, COLUMN, ROW

full_width = Pack(flex=1)
full_column = Pack(flex=1,direction=COLUMN)
full_row = Pack(flex=1,direction=ROW)
main_box_style = Pack(padding=10, direction=COLUMN, flex=1)
grid_row_btn = Pack(direction=ROW, flex=1)
generic_style = Pack(padding=10, flex=1)
btn_number = Pack(padding=5, flex=1)



